@@ -4,10 +4,10 @@
 //!
 //! [OpenSSL's documentation]: https://www.openssl.org/docs/fips/UserGuide-2.0.pdf
 use crate::ffi;
+use openssl_macros::corresponds;
 
 /// Determines if the library is running in the FIPS 140-2 mode of operation.
-///
-/// This corresponds to `FIPS_mode`.
+#[corresponds(FIPS_mode)]
 pub fn enabled() -> bool {
     unsafe { ffi::FIPS_mode() != 0 }
 }
